@@ -1,5 +1,5 @@
 from pydantic import BaseModel,Field
-from data.enums.logycastatusenum import LogycaStatusEnum
+from logyca.data.enums.logycastatusenum import LogycaStatusEnum
 from typing import Any
 from http import HTTPStatus
 
